@@ -1,4 +1,3 @@
-
 from django.db import models
 from django_peeringdb.models import URLField, LG_URLField
 
@@ -7,10 +6,11 @@ class FieldModel(models.Model):
     url = URLField(null=True, blank=True)
 
     class Meta:
-        app_label = 'django_peeringdb.tests'
+        app_label = "django_peeringdb.tests"
 
 
 class LG_FieldModel(models.Model):
     url = LG_URLField(null=True, blank=True)
+
     class Meta:
-        app_label = 'django_peeringdb.tests'
+        app_label = "django_peeringdb.tests"
